/*
 * langues.c --- language package.
 *
 * Copyright (c) 1997-2005, 2015 by Pascal Wassong All Rights Reserved.
 *
 * This file is part of Natch.
 *
 * Natch is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Natch is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include	"common.h"

#include	"langues.h"

static	eLanguage	Language;
static	char*		Strings[numberOfStrings][numberOfLanguages] =
{
    {"", "", ""},					/* eStrEmpty */
    /* eStrCopyright */
    {"Copyright (C) 1997,98,99,2001-2005,2016 Pascal Wassong",
     "Copyright (C) 1997,98,99,2001-2005,2016 Pascal Wassong",
     "Copyright (C) 1997,98,99,2001-2005,2016 Pascal Wassong"},
    {"RPDTFC", "KPQRBS", "KBDTLS"},		/* eStrInitialOfPieces */
    {"RDTFCCP", "KQRBNSP", "KDTLSSB"},		/* eStrForsytheInitials */
    {"coups", "moves", "Zuegen"},                /* eStrMoves */
    {"demi-coups", "single moves", "Halbzuegen"},	/* eStrHalfMoves */
    {",0", ".0", ",0"},                /* eStrDotZero */
    {",5", ".5", ",5"},                /* eStrDotFive */
    {"B=%d N=%d", "W=%d B=%d", "W=%d S=%d"},		/* eStrCoupsRestants */
    {"Recherche", "Searching", " Suche   "},		/* eStrRecherche */
    {"position",  "position",  "Stellung"},		/* eStrPosition */
    {"Solution", "Solution", "Loesung"},		/* eStrSolution */
    {"voir solution", "see solution", "sehe Loesung"},	/* eStrSeeSolution */
    {"Stop? O/N", "Stop? Y/N", "Stop? J/N"},		/* eStrStop */
    {"Suite O/N", "Skip? Y/N", "Skip? J/N"},		/* eStrSkip */
     {"Temps de resolution : ",
      "Resolution time: ",
     "Loesung zeit: "},			/* eStrResolutionTime */
     {"La resolution commence le %s",
      "The resolution begins at %s",
     "Anfang der Loesung am %s"},	/* eStrBeginResolution */
     {"La resolution finit le %s",
      "The resolution ends at %s",
     "Ende der Loesung am %s"},		/* eStrEndResolution */
     {"La resolution s'arrete apres la solution %d",
      "The resolution stops after solution %d",
     "Ende nach der Loesung %d"},	/* eStrStoppedBySolution */
    /* eStrStoppedByUser */
    {"La resolution est interrompue par l'utilisateur a la position %d",
     "The resolution is interrupted by the user at position %d",
     "Der Benutzer hat die Loesung an Stellung %d unterbrochen"},
    { "Nombre de coups blancs : %d\n",
      "Number of white moves: %d\n",
      "Weisse Zuegen Anzahl: %d\n"},	/* eStrNumberOfWhiteMoves */
    { "Coup %2d : ", "Move %2d: ", "Zug %2d: " },	/* eStrMove */
    { "%ld solution(s) deja trouvee(s).\n",
      "%ld solution(s) already found.\n",
      "%ld Loesung(eng) schon gefunden.\n" },	/* eStrSolutionsFound */
    { "La resolution continue a la position %ld\n\n",
      "Resolution continues at position %ld\n\n",
      "Loesung geht an Stellung %ld weiter\n\n" },	/* eStrContinueAt */
    { "La position %ld a ete sautee par l'utilisateur\n",
      "Position %ld has been skipped by the user\n",
      "Der Benutzer hat die Stellung %ld ausgelassen\n"},/*eStrPositionSkipped*/

    /* eStrTotalSolution */
    {"Solution trouvee :", "Solution found:", "Loesung gefunden:"},
    /* eStrTotalSolutions */
    {"Solutions trouvees :", "Solutions found:", "Loesungen gefunden:"},
    /* eStrTotalPosition */
    {"Position analysee :", "Position analysed:", "Stellung untersucht:"},
    /* eStrTotalPositions */
    {"Positions analysees :",
     "Positions analysed:",
     "Stellungen untersucht:"},
    /* eStrSolutionNotSearched */
    {"non cherchee",
     "not searched",
     "nicht gesucht"},
};

static char		Chars[numberOfChars][numberOfLanguages] =
{
    {' ', ' ', ' '},			/* eCharEmpty */
    {'o', 'y', 'j'},			/* eCharYes */
    {'n', 'n', 'n'},			/* eCharNo */
};

void
langSetLanguage(eLanguage langue)
{
    Language = langue;
}

char
langGetChar(eCharId charId)
{
    return (Chars[charId][Language]);
}

const char*
langGetString(eStringId stringId)
{
    return (Strings[stringId][Language]);
}
