/*
 * twin_squares.h --- twin squares package
 *
 * Copyright (c) 2001, 2002, 2009, 2015 by Pascal Wassong All Rights Reserved.
 *
 * This file is part of Natch.
 *
 * Natch is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Natch is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef TWIN_SQUARE_H
#define	TWIN_SQUARE_H

#include	"types.h"

typedef enum
{
    e_vertical,
    e_horizontal,
    e_up_right,
    e_up_left
} twin_direction_t;

typedef struct one_twin_t
{
    square_t		first;
    square_t		second;
    twin_direction_t	direction;
    piece_type_t	type;
    colour_t		colour;
    square_t            origin;
} one_twin_t;

typedef struct twin_squares_t
{
    one_twin_t		twins[ 32 ];
    unsigned int	nb_twins;
} twin_squares_t;

void create_twin_squares(
    const piece_t*	pieces,
    unsigned int	nb_pieces,
    twin_squares_t*     twin_squares);

void replace_twin_square(
    twin_squares_t* twin_squares,
    square_t origin,
    square_t first,
    square_t second);

void add_twin_square(
    twin_squares_t* twin_squares,
    square_t first,
    square_t second,
    twin_direction_t direction,
    piece_type_t type,
    colour_t colour,
    square_t origin);

void remove_last_twin_square(twin_squares_t* twin_squares);

square_t find_twin_square(
    const twin_squares_t* twin_squares,
    square_t		square,
    twin_direction_t	direction,
    piece_type_t	type,
    square_t            origin);

void print_twin_squares(const twin_squares_t* twin_squares);

extern square_t	No_Twin_Square ;

#endif /* TWIN_SQUARE_H */
